@@ -1,5 +1,7 @@
 """
-Main interface for networkmanager service literal definitions.
+Type annotations for networkmanager service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/literals.html)
 
 Usage::
 
